@@ -1,7 +1,7 @@
 package Log::Any::For::Class;
 
-our $DATE = '2015-08-17'; # DATE
-our $VERSION = '0.26'; # VERSION
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.27'; # VERSION
 
 use 5.010001;
 use strict;
@@ -123,7 +123,7 @@ Log::Any::For::Class - Add logging to class
 
 =head1 VERSION
 
-This document describes version 0.26 of Log::Any::For::Class (from Perl distribution Log-Any-For-Class), released on 2015-08-17.
+This document describes version 0.27 of Log::Any::For::Class (from Perl distribution Log-Any-For-Class), released on 2015-09-03.
 
 =head1 SYNOPSIS
 
@@ -141,9 +141,8 @@ module, since this module uses add_logging_to_package() as its backend.
 
 =head2 add_logging_to_class(%args) -> any
 
-{en_US Add logging to class}.
+Add logging to class.
 
-{en_US 
 Logging will be done using Log::Any.
 
 Currently this function adds logging around method calls, e.g.:
@@ -152,49 +151,40 @@ Currently this function adds logging around method calls, e.g.:
  <- Class::method() = RESULT
  ...
 
-}
-
 Arguments ('*' denotes required arguments):
 
 =over 4
 
 =item * B<classes>* => I<array[str]>
 
-{en_US Classes to add logging to}.
+Classes to add logging to.
 
 =item * B<filter_methods> => I<array[str]>
 
-{en_US Filter methods to add logging to}.
+Filter methods to add logging to.
 
-{en_US 
 The default is to add logging to all non-private methods. Private methods are
 those prefixed by C<_>.
-}
 
 =item * B<import_hook> => I<bool> (default: 0)
 
-{en_US Whether to install import (@INC) hook instead}.
+Whether to install import (@INC) hook instead.
 
-{en_US 
 If this setting is true, then instead of installing logging to all existing
 packages, an @INC import hook will be installed instead so that subsequent
 modules that are loaded and that match C<packages> will be logged. So to log all
 subsequent loaded modules, you can set C<packages> to C<['.*']>.
-}
 
 =item * B<logger_args> => I<any>
 
-{en_US Pass arguments to logger}.
+Pass arguments to logger.
 
-{en_US 
 This allows passing arguments to logger routine.
-}
 
 =item * B<postcall_logger> => I<code>
 
-{en_US Supply custom postcall logger}.
+Supply custom postcall logger.
 
-{en_US 
 Just like C<precall_logger>, but code will be called after subroutine/method is
 called. Code will be given a hashref argument \%args containing these keys:
 C<args> (arrayref, a shallow copy of the original @_), C<orig> (coderef, the
@@ -203,13 +193,11 @@ subroutine/method name), C<result> (arrayref, the subroutine/method result),
 C<logger_args> (arguments given when adding logging).
 
 You can use this mechanism to customize logging.
-}
 
 =item * B<precall_logger> => I<code>
 
-{en_US Supply custom precall logger}.
+Supply custom precall logger.
 
-{en_US 
 Code will be called when logging subroutine/method call. Code will be given a
 hashref argument \%args containing these keys: C<args> (arrayref, a shallow copy
 of the original @_), C<orig> (coderef, the original subroutine/method), C<name>
@@ -253,7 +241,6 @@ be supplied via environment C<LOG_SUB_ARGS>.
 
 Whether to display subroutine result when logging subroutine exit. The default
 can also be set via environment C<LOG_SUB_RESULT>.
-}
 
 =back
 
@@ -271,7 +258,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Log-Any-Fo
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Log-Any-For-Class>.
+Source repository is at L<https://github.com/perlancar/perl-Log-Any-For-Class>.
 
 =head1 BUGS
 
